@@ -1,6 +1,8 @@
+import json
 import logging
 
 from fastapi import Request
+from fastapi.exceptions import RequestValidationError
 from fastapi.responses import JSONResponse
 
 from web_error.error import HttpException
@@ -18,12 +20,17 @@ def exception_handler(request: Request, exc: Exception):
         "code": None,
     }
 
+    if isinstance(exc, RequestValidationError):
+        response["message"] = "Request validation error."
+        response["debug_message"] = json.loads(exc.json())
+        status = 422
+
     if isinstance(exc, HttpException):
         response = exc.marshal()
         status = exc.status
 
     if status >= 500:
-        logger.exception(message)
+        logger.exception(message, exc_info=(type(exc), exc, exc.__traceback__))
 
     return JSONResponse(
         status_code=status,
